Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1395)

Unified Diff: content/browser/renderer_host/render_process_host.h

Issue 6319001: Support window.opener after a process swap. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Update comments. Created 9 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/renderer_host/render_process_host.h
diff --git a/content/browser/renderer_host/render_process_host.h b/content/browser/renderer_host/render_process_host.h
index a954d02adca29ba3b728738f7ea54321f78ebc88..e4c1860ba4f4580ddc522daaa92b7d9d8bc03525 100644
--- a/content/browser/renderer_host/render_process_host.h
+++ b/content/browser/renderer_host/render_process_host.h
@@ -18,7 +18,7 @@
#include "ui/gfx/surface/transport_dib.h"
class Profile;
-struct ViewMsg_ClosePage_Params;
+struct ViewMsg_SwapOut_Params;
namespace base {
class SharedMemory;
@@ -166,12 +166,12 @@ class RenderProcessHost : public IPC::Channel::Sender,
// the specified render widget.
virtual void CancelResourceRequests(int render_widget_id) = 0;
// Called on the UI thread to simulate a ClosePage_ACK message to the
// ResourceDispatcherHost. Necessary for a cross-site request, in the case
// that the original RenderViewHost is not live and thus cannot run an
- // onunload handler.
- virtual void CrossSiteClosePageACK(
- const ViewMsg_ClosePage_Params& params) = 0;
+ // unload handler.
+ virtual void CrossSiteSwapOutACK(
+ const ViewMsg_SwapOut_Params& params) = 0;
// Called on the UI thread to wait for the next UpdateRect message for the
// specified render widget. Returns true if successful, and the msg out-
@@ -166,12 +166,12 @@ class RenderProcessHost : public IPC::Channel::Sender,
// the specified render widget.
virtual void CancelResourceRequests(int render_widget_id) = 0;
- // Called on the UI thread to simulate a ClosePage_ACK message to the
+ // Called on the UI thread to simulate a SwapOut_ACK message to the
// ResourceDispatcherHost. Necessary for a cross-site request, in the case
// that the original RenderViewHost is not live and thus cannot run an

Powered by Google App Engine
This is Rietveld 408576698